ProSHADE: src/proshade/ProSHADE_typedefs.hpp Source File

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

ProSHADE_typedefs.hpp
Go to the documentation of this file.
1
22 //==================================================== ProSHADE
23 #include "ProSHADE_version.hpp"
24
25 //==================================================== Standard library
26 #include <iostream>
27 #include <fstream>
28 #include <ctime>
29 #include <cmath>
30 #include <numeric>
31 #include <string>
32 #include <vector>
33 #include <exception>
34 #include <complex>
35 #include <algorithm>
36 #include <getopt.h>
37 #include <iomanip>
38 #include <utility>
39
40 //==================================================== Overinclusion protection
41 #ifndef __PROSHADE_TYPEDEFS__
42 #define __PROSHADE_TYPEDEFS__
43
44 //==================================================== The Task data type
45 enum ProSHADE_Task { NA, Distances, Symmetry, OverlayMap, MapManip };
46
47 //==================================================== ProSHADE Typedefs
48 typedef float proshade_single;
49 typedef double proshade_double;
50 typedef signed long int proshade_signed;
51 typedef unsigned long int proshade_unsign;
52 typedef double proshade_complex[2];
53 typedef double proshade_triplet[3];
54
55 #endif
56